@@ -30,28 +30,31 @@ public class TorperfResultImpl extends DescriptorImpl
     List<Descriptor> parsedDescriptors = new ArrayList<>();
     String descriptorString = new String(rawDescriptorBytes,
         StandardCharsets.UTF_8);
-    Scanner scanner = new Scanner(descriptorString).useDelimiter("\r?\n");
-    String typeAnnotation = "";
-    while (scanner.hasNext()) {
-      String line = scanner.next();
-      if (line.startsWith("@type torperf ")) {
-        String[] parts = line.split(" ");
-        if (parts.length != 3) {
-          throw new DescriptorParseException("Illegal line '" + line
-              + "'.");
+    try (Scanner scanner =
+                 new Scanner(descriptorString).useDelimiter("\r?\n")) {
+      String typeAnnotation = "";
+      while (scanner.hasNext()) {
+        String line = scanner.next();
+        if (line.startsWith("@type torperf ")) {
+          String[] parts = line.split(" ");
+          if (parts.length != 3) {
+            throw new DescriptorParseException("Illegal line '" + line
+                    + "'.");
+          }
+          String version = parts[2];
+          if (!version.startsWith("1.")) {
+            throw new DescriptorParseException("Unsupported version in "
+                    + " line '" + line + "'.");
+          }
+          typeAnnotation = line + "\n";
+        } else {
+          /* XXX21932 */
+          parsedDescriptors.add(new TorperfResultImpl(
+                  (typeAnnotation + line + "\n")
+                          .getBytes(StandardCharsets.UTF_8),
+                  descriptorFile));
+          typeAnnotation = "";
         }
-        String version = parts[2];
-        if (!version.startsWith("1.")) {
-          throw new DescriptorParseException("Unsupported version in "
-              + " line '" + line + "'.");
-        }
-        typeAnnotation = line + "\n";
-      } else {
-        /* XXX21932 */
-        parsedDescriptors.add(new TorperfResultImpl(
-            (typeAnnotation + line + "\n").getBytes(StandardCharsets.UTF_8),
-            descriptorFile));
-        typeAnnotation = "";
       }
     }
     return parsedDescriptors;
@@ -74,8 +77,7 @@ public class TorperfResultImpl extends DescriptorImpl
       throw new DescriptorParseException("Blank lines are not allowed.");
     }
     String[] parts = line.split(" ");
-    for (int i = 0; i < parts.length; i++) {
-      String keyValue = parts[i];
+    for (String keyValue : parts) {
       String[] keyValueParts = keyValue.split("=");
       if (keyValueParts.length != 2) {
         throw new DescriptorParseException("Illegal key-value pair in "
@@ -86,7 +88,7 @@ public class TorperfResultImpl extends DescriptorImpl
       String value = keyValueParts[1];
       switch (key) {
         case "SOURCE":
-          this.parseSource(value, keyValue, line);
+          this.parseSource(value);
           break;
         case "FILESIZE":
           this.parseFileSize(value, keyValue, line);
@@ -152,22 +154,22 @@ public class TorperfResultImpl extends DescriptorImpl
           this.parseUsedBy(value, keyValue, line);
           break;
         case "ENDPOINTLOCAL":
-          this.parseEndpointLocal(value, keyValue, line);
+          this.parseEndpointLocal(value);
           break;
         case "ENDPOINTPROXY":
-          this.parseEndpointProxy(value, keyValue, line);
+          this.parseEndpointProxy(value);
           break;
         case "ENDPOINTREMOTE":
-          this.parseEndpointRemote(value, keyValue, line);
+          this.parseEndpointRemote(value);
           break;
         case "HOSTNAMELOCAL":
-          this.parseHostnameLocal(value, keyValue, line);
+          this.parseHostnameLocal(value);
           break;
         case "HOSTNAMEREMOTE":
-          this.parseHostnameRemote(value, keyValue, line);
+          this.parseHostnameRemote(value);
           break;
         case "SOURCEADDRESS":
-          this.parseSourceAddress(value, keyValue, line);
+          this.parseSourceAddress(value);
           break;
         default:
           if (key.startsWith("DATAPERC")) {
@@ -216,8 +218,7 @@ public class TorperfResultImpl extends DescriptorImpl
     }
   }
 
-  private void parseSource(String value, String keyValue, String line)
-      throws DescriptorParseException {
+  private void parseSource(String value) {
     this.source = value;
   }
 
@@ -288,13 +289,16 @@ public class TorperfResultImpl extends DescriptorImpl
 
   private void parseDidTimeout(String value, String keyValue, String line)
       throws DescriptorParseException {
-    if (value.equals("1")) {
-      this.didTimeout = true;
-    } else if (value.equals("0")) {
-      this.didTimeout = false;
-    } else {
-      throw new DescriptorParseException("Illegal value in '" + keyValue
-          + "' in line '" + line + "'.");
+    switch (value) {
+      case "1":
+        this.didTimeout = true;
+        break;
+      case "0":
+        this.didTimeout = false;
+        break;
+      default:
+        throw new DescriptorParseException("Illegal value in '" + keyValue
+            + "' in line '" + line + "'.");
     }
   }
 
@@ -302,7 +306,7 @@ public class TorperfResultImpl extends DescriptorImpl
       String line) throws DescriptorParseException {
     String key = keyValue.substring(0, keyValue.indexOf("="));
     String percentileString = key.substring("DATAPERC".length());
-    int percentile = -1;
+    int percentile;
     try {
       percentile = Integer.parseInt(percentileString);
     } catch (NumberFormatException e) {
@@ -378,27 +382,27 @@ public class TorperfResultImpl extends DescriptorImpl
     this.usedBy = this.parseInt(value, keyValue, line);
   }
 
-  private void parseEndpointLocal(String value, String keyValue, String line) {
+  private void parseEndpointLocal(String value) {
     this.endpointLocal = value;
   }
 
-  private void parseEndpointProxy(String value, String keyValue, String line) {
+  private void parseEndpointProxy(String value) {
     this.endpointProxy = value;
   }
 
-  private void parseEndpointRemote(String value, String keyValue, String line) {
+  private void parseEndpointRemote(String value) {
     this.endpointRemote = value;
   }
 
-  private void parseHostnameLocal(String value, String keyValue, String line) {
+  private void parseHostnameLocal(String value) {
     this.hostnameLocal = value;
   }
 
-  private void parseHostnameRemote(String value, String keyValue, String line) {
+  private void parseHostnameRemote(String value) {
     this.hostnameRemote = value;
   }
 
-  private void parseSourceAddress(String value, String keyValue, String line) {
+  private void parseSourceAddress(String value) {
     this.sourceAddress = value;
   }
 
